# ImportRequestTypeDto


## Enum

* `TEST_CASE_CSV` (value: `'test_case_csv'`)

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


